#!/usr/bin/perl -w

use strict;

# Copyright (C) 2004 Canonical Ltd.
# Copyright (C) 2011 Felix Geyer <debfx@ubuntu.com>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.

# most of the code is shamelessly copied from dh_translations

my $domain;

sub process_desktop {
    my @lines = @{$_[0]};
    my @result;
    my $in_desktop_entry = 0;
    my $added_domain = 0;
    foreach (@lines) {

        if (/^[A-Za-z-0-9-]*Gettext-Domain\s*=/) {
            $added_domain = 1;
        }

        # catch section headers
        if (/^\[\s*(.+)\s*\]/) {
            $in_desktop_entry = ($1 eq 'Desktop Entry');
        }

        # if we are ending the desktop section, append the domain
        if (/^\s*$/ && $in_desktop_entry && !$added_domain) {
            push @result, "X-Ubuntu-Gettext-Domain=$domain\n";
            $added_domain = 1;
        }

        push @result, $_;
    }

    # single-section .desktop files without ending empty lines
    if ($in_desktop_entry && !$added_domain) {
        push @result, "X-Ubuntu-Gettext-Domain=$domain\n";
    }

    return @result;
}

if (@ARGV != 2) {
    print STDERR "Invalid number of arguments.\n";
    exit 1;
}

$domain = $ARGV[0];
my $listFile = $ARGV[1];

my @listLines;
open F, $listFile or die "open $listFile: $!";
@listLines = <F>;
close F;

foreach (@listLines) {
    my $f = $_;

    my @lines;
    open F, $f or die "open $f: $!";
    @lines = <F>;
    close F;

    @lines = process_desktop \@lines;

    # write back modified result
    open F, ">$f" or die "open $f: $!";
    foreach (@lines) {
        print F $_;
    }
    close F;
}
